@@ -85,21 +85,21 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class SecurityGroup(
-    aws_cdk.aws_ec2.SecurityGroup,
+    _aws_cdk_aws_ec2_ceddda9d.SecurityGroup,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-security-group.SecurityGroup",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         disable_inline_rules: typing.Optional[builtins.bool] = None,
@@ -115,18 +115,7 @@ class SecurityGroup(
         :param security_group_name: The name of the security group. For valid values, see the GroupName parameter of the CreateSecurityGroup action in the Amazon EC2 API Reference. It is not recommended to use an explicit group name. Default: If you don't specify a GroupName, AWS CloudFormation generates a unique physical ID and uses that ID for the group name.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                vpc: aws_cdk.aws_ec2.IVpc,
-                allow_all_outbound: typing.Optional[builtins.bool] = None,
-                description: typing.Optional[builtins.str] = None,
-                disable_inline_rules: typing.Optional[builtins.bool] = None,
-                security_group_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__926b26b23b0eaec74a1742f5573d73d4d125b9edf7ebe67106cf45392a4849ea)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SecurityGroupProps(
@@ -148,7 +137,7 @@ class SecurityGroup(
 
 @jsii.data_type(
     jsii_type="@pepperize/cdk-security-group.SecurityGroupProps",
-    jsii_struct_bases=[aws_cdk.aws_ec2.SecurityGroupProps],
+    jsii_struct_bases=[_aws_cdk_aws_ec2_ceddda9d.SecurityGroupProps],
     name_mapping={
         "vpc": "vpc",
         "allow_all_outbound": "allowAllOutbound",
@@ -157,11 +146,11 @@ class SecurityGroup(
         "security_group_name": "securityGroupName",
     },
 )
-class SecurityGroupProps(aws_cdk.aws_ec2.SecurityGroupProps):
+class SecurityGroupProps(_aws_cdk_aws_ec2_ceddda9d.SecurityGroupProps):
     def __init__(
         self,
         *,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         disable_inline_rules: typing.Optional[builtins.bool] = None,
@@ -175,22 +164,13 @@ class SecurityGroupProps(aws_cdk.aws_ec2.SecurityGroupProps):
         :param security_group_name: The name of the security group. For valid values, see the GroupName parameter of the CreateSecurityGroup action in the Amazon EC2 API Reference. It is not recommended to use an explicit group name. Default: If you don't specify a GroupName, AWS CloudFormation generates a unique physical ID and uses that ID for the group name.
         '''
         if __debug__:
-            def stub(
-                *,
-                vpc: aws_cdk.aws_ec2.IVpc,
-                allow_all_outbound: typing.Optional[builtins.bool] = None,
-                description: typing.Optional[builtins.str] = None,
-                disable_inline_rules: typing.Optional[builtins.bool] = None,
-                security_group_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__13c8185f9a5328c9cf9ea3bfbcf7e157ec7de6b330c89fd8788554cbce205258)
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument disable_inline_rules", value=disable_inline_rules, expected_type=type_hints["disable_inline_rules"])
             check_type(argname="argument security_group_name", value=security_group_name, expected_type=type_hints["security_group_name"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "vpc": vpc,
         }
         if allow_all_outbound is not None:
@@ -203,11 +183,11 @@ class SecurityGroupProps(aws_cdk.aws_ec2.SecurityGroupProps):
             self._values["security_group_name"] = security_group_name
 
     @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''The VPC in which to create the security group.'''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.IVpc, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, result)
 
     @builtins.property
     def allow_all_outbound(self) -> typing.Optional[builtins.bool]:
@@ -285,3 +265,27 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__926b26b23b0eaec74a1742f5573d73d4d125b9edf7ebe67106cf45392a4849ea(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    allow_all_outbound: typing.Optional[builtins.bool] = None,
+    description: typing.Optional[builtins.str] = None,
+    disable_inline_rules: typing.Optional[builtins.bool] = None,
+    security_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__13c8185f9a5328c9cf9ea3bfbcf7e157ec7de6b330c89fd8788554cbce205258(
+    *,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    allow_all_outbound: typing.Optional[builtins.bool] = None,
+    description: typing.Optional[builtins.str] = None,
+    disable_inline_rules: typing.Optional[builtins.bool] = None,
+    security_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
